import { RelativeMiddlewareOptions, SerializeMiddleware } from "@smithy/types";
interface PreviouslyResolved {
    bucketEndpoint?: boolean;
}
/**
 * @internal
 */
export declare function bucketEndpointMiddleware(options: PreviouslyResolved): SerializeMiddleware<any, any>;
/**
 * @internal
 */
export declare const bucketEndpointMiddlewareOptions: RelativeMiddlewareOptions;
export {};
